Shopifex.Shops (Shopifex v2.4.0) View Source

The Shops context. This module calls the default Shopifex.ShopsContextClient, which in turn calls the functions defined in the ShopsContext behaviour. You can swap out the default client for your own implementation by setting the :shops_context_client config value for the :shopifex app to a module that uses Shopifex.ShopsContext and overrides various functions.

Link to this section Summary

Link to this section Functions

Link to this function

change_grant(grant, attrs)

Link to this function

change_plan(plan, attrs)

Link to this function

configure_webhooks(shop)

Link to this function

create_shop_grant(shop, grants)

Link to this function

delete_webhook(shop, id)

Link to this function

get_current_webhooks(shop)

Link to this function

list_plans_granting_guard(guard)

Link to this function

update_grant(grant, attrs)

Link to this function

update_plan(plan, attrs)

Link to this function

update_shop(shop, params)

View Source